/**
  EntierPositif est une representation OO d'un entier dont la
  valeur ne peut pas etre negative.

  @author      Patrice Roy
  @version     %I%, %G%
  @since       1.0
 */
public class EntierPositif
{
   private static final int VALEUR_DFAUT = 0;
   private int m_Valeur;

   /**
     Classe interne permettant de reprsenter une valeur hors
     des bornes valables pour un entier positif

     @since     1.0
    */
   public static class ValeurHorsBornes
      extends Exception
   {
      /**
        Constructeur parametrique, representant a la fois un cas de
        valeur hors bornes et un message decrivant cette situation

        @param Valeur    la valeur hors bornes en question
        @since     1.0
       */
      public ValeurHorsBornes (final int Valeur)
      {
         super("Valeur hors bornes: " + Valeur);
      }
   }

   /**
     Constructeur par defaut. L'entier positif resultant aura une
     valeur nulle, qu'on estime etre celle attendue d'un entier
     par defaut.

     @since     1.0
    */
   public EntierPositif ()
   {
      SetValeurBrut (VALEUR_DFAUT);
   }

   /**
     Constructeur parametrique, public et securitaire. Lance une exception
     de type <code>ValeurHorsBornes</code> si la valeur passee en parametre est illegale.

     @param Valeur    la valeur qu'on souhaite donner a l'entier positif
     @since     1.0
    */
   public EntierPositif (final int Valeur)
      throws ValeurHorsBornes
   {
      SetValeur (Valeur);
   }

   /**
     Constructeur par copie.

     @param e   l'entier positif dont on souhaite creer une copie
     @since     1.0
    */
   public EntierPositif (final EntierPositif e)
   {
      SetValeurBrut (e.GetValeur ());
   }

   /**
     Manipulateur de premier ordre, public et securitaire. Lance une
     exception de type <code>ValeurHorsBornes</code> si la valeur passee en parametre
     est illegale.

     @param Valeur    la nouvelle valeur qu'on souhaite donner a l'entier positif
     @since     1.0
    */
   public void SetValeur (final int Valeur)
      throws ValeurHorsBornes
   {
      if (Valeur < 0)
         throw new ValeurHorsBornes (Valeur);
      SetValeurBrut (Valeur);
   }

   /**
     Manipulateur de premier ordre, prive et sans protection. Voue
     a un usage interne et securise au pralable. Pour tout acces en
     ecriture a la valeur de l'objet utilisant une nouvelle valeur
     dont la validite n'est pas garantie, privilegiez la version
     publique SetValeur() ( venir).

     @param Valeur    la nouvelle valeur de l'entier positif
     @since     1.0
    */
   private void SetValeurBrut (final int Valeur)
   {
      m_Valeur = Valeur;
   }

   /**
     Accesseur de premier ordre. Permet de connaitre la valeur de
     l'entier positif. Ne modifie en rien le contenu de l'objet.

     @return          la valeur courante de l'entier positif.
     @since     1.0
    */
   public int GetValeur ()
   {
      return m_Valeur;
   }

   /**
     Manipulateur de premier ordre, public et sans protection. Une
     erreur de design, qui introduit un risque de bris d'integrite
     dans un entier positif. Privilegiez <a href=#SetValeur(int)>SetValeur(int)</a>

     @param Valeur    la nouvelle valeur de l'entier positif
     @deprecated
     @since     1.0
    */
   public void SetValeurPatch (final int Valeur)
   {
      m_Valeur = Valeur;
   }

}
